/*
 * This file is part of smolbote. It's copyrighted by the contributors recorded
 * in the version control history of the file, available from its original
 * location: https://neueland.iserlohn-fortress.net/gitea/aqua/smolbote
 *
 * SPDX-License-Identifier: GPL-3.0
 */

#ifndef SMOLBOTE_BROWSER_H
#define SMOLBOTE_BROWSER_H

#include "session.hpp"
#include <QJsonObject>
#include <QMenu>
#include <QPluginLoader>
#include <QVector>
#include <functional>
#include <memory>
#include <singleapplication.h>

class UrlFilter;
class Configuration;
class BookmarksWidget;
class DownloadsWidget;
class MainWindow;
class WebProfile;
class WebProfileManager;
class Browser final : public SingleApplication
{
    Q_OBJECT

public:
    explicit Browser(int &argc, char *argv[], bool allowSecondary = true);
    ~Browser() final;

public slots:
    void about();

public:
    // interface
    void loadProfiles(const QStringList &profilePaths);
    void loadPlugins(
        const QStringList &paths,
        const std::function<void(const QPluginLoader *)> &callback = [](const auto) {});
    void setup();

    const QVector<MainWindow *> windows() const
    {
        return qAsConst(m_windows);
    }

    BookmarksWidget *bookmarks() const
    {
        return m_bookmarks.get();
    }
    DownloadsWidget *downloads() const
    {
        return m_downloads.get();
    }

public slots:
    void showWidget(QWidget *widget, MainWindow *where) const;
    void open(const QVector<Session::MainWindow> &data, bool merge = true);

private:
    struct PluginInfo {
        explicit PluginInfo(QPluginLoader *l)
        {
            this->loader = l;
        }
        ~PluginInfo()
        {
            loader->unload();
            for(auto *m : qAsConst(menus))
                m->deleteLater();
        };

        QPluginLoader *loader;
        QVector<QMenu *> menus;
    };
    void addPluginTo(PluginInfo *info, MainWindow *window);

    Q_DISABLE_COPY(Browser)

    std::shared_ptr<BookmarksWidget> m_bookmarks;
    std::unique_ptr<DownloadsWidget> m_downloads;
    WebProfileManager *m_profileManager = nullptr;
    QVector<UrlFilter *> m_filters;

    QVector<MainWindow *> m_windows;
    QVector<PluginInfo *> m_plugins;
};

#endif // SMOLBOTE_BROWSER_H
